(create-src-dirs! ws-path src-dir top-dirs)This function assumes that the workspace is already created. It creates 'ws-dir'/'src-dir' + all directories given in the incoming 'top-dirs' parameter, beneath that directory.
This function assumes that the workspace is already created. It creates 'ws-dir'/'src-dir' + all directories given in the incoming 'top-dirs' parameter, beneath that directory.
(interface-of ws-path top-dir component)(interface-of ws-path top-dir component interfaces)(used-entities ws-path top-dir)(used-entities ws-path top-dir system-or-env)(used-entities ws-path top-dir type system-or-env)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |